urllib3: HTTP library with thread-safe connection pooling, file post, and more
==============================================================================

Description
-----------

HTTP library with thread-safe connection pooling, file post, and more

License
-------

MIT

Upstream Contact
----------------

https://pypi.org/project/urllib3/

